@@ -1,5 +1,5 @@
 #  This file is part of OctoBot (https://github.com/Drakkar-Software/OctoBot)
-#  Copyright (c) 2021 Drakkar-Software, All rights reserved.
+#  Copyright (c) 2022 Drakkar-Software, All rights reserved.
 #
 #  OctoBot is free software; you can redistribute it and/or
 #  modify it under the terms of the GNU General Public License
@@ -128,11 +128,13 @@ def _create_startup_config(logger):
 
 def _read_config(config, logger):
     try:
-        config.read(should_raise=False, fill_missing_fields=True)
+        config.read(should_raise=True, fill_missing_fields=True)
     except errors.NoProfileError:
         _repair_with_default_profile(config, logger)
         config = _create_configuration()
         config.read(should_raise=False, fill_missing_fields=True)
+    except Exception as e:
+        raise errors.ConfigError(e)
 
 
 def _validate_config(config, logger):
@@ -201,6 +203,9 @@ def start_octobot(args):
         # add args to config
         update_config_with_args(args, config, logger)
 
+        # switch environments if necessary
+        octobot_community.IdentifiersProvider.use_environment_from_config(config)
+
         # show terms
         _log_terms_if_unaccepted(config, logger)
 
@@ -245,9 +250,9 @@ def start_octobot(args):
 
         commands.run_bot(bot, logger)
 
-    except errors.ConfigError:
+    except errors.ConfigError as e:
         logger.error("OctoBot can't start without a valid " + common_constants.CONFIG_FILE
-                     + " configuration file." + "\nYou can use " +
+                     + " configuration file.\nError: " + str(e) + "\nYou can use " +
                      constants.DEFAULT_CONFIG_FILE + " as an example to fix it.")
         os._exit(-1)
 
